; Bling Text V1.4 (1-2008)
; Create animated or static bling text with drop shadow
;
; Created by Scott Mosteller 
; Bling Graphic Animations and Patterns by Tonya Marshall
;
;********************************* IMPORTANT ****************************************
; This script requires a set of patterns that are included in the zip file (/patterns)
;
; Copy these patterns to your local pattern folder in order to use this script
;**************************************************************************************
;
; Checking the animate toggle will direct script to generate 3 text layers with the selected font
; The text will be filled with the selected pattern and bling type
;
; Each layer will be shadowed and semifattened with the background color, for use as an animated .GIF
; All that is required as this point is to simply save the image as an animated .GIF
;
; Leaving the animate toggle unchecked will direct the script to generate a static image
; The static images will contain one shadowed text layer, semifattened, along the background layer. 
;
; Selecting "Raw Layers Only" returns only the raw layers. To more easily work with the raw layers,
; Bring up the layers dialog, right click on "Background" layer and select "Alpha to selection"        
; Then, simply crop the image. You are now ready to work with the script's raw layers.
; No semi-flatten function is applied to the raw image layers
;
;
; Comments and questions directed to http://gimpchat,com
;
; Compatible with all Gimp Versions 2.x - Enjoy!
;
; ------------
;| Change Log |
; ------------ 
; V1.0 - Initial Release
; V1.1 - Added shadow x/y offset, Shadow Opacity, Autocrop and Raw Layers Options
; V1.2 - Added four new Bling Patterns
; V1.3 - Added Heart Patterns and Checkered pattern              
; V1.4 - Updated Menus Locations for Gimp 2.6 - Changed Default Settings 
;

;Tosilscript-fugp܂B
;http://www.geocities.jp/gimproject/scripts/layers-view-delete.html

(define (script-fu-layers-view-none image drawable)
 (let* ((layers (gimp-image-get-layers image))
	    (number-layers (car layers))
	    (layer-array (cadr layers))
	    (layer-count 0)
	    (layer))
    (set! layer-count 0)
    (while (< layer-count number-layers)
           (set! layer (aref layer-array layer-count))
           (gimp-layer-set-visible layer FALSE)
           (set! layer-count (+ layer-count 1)))
))
(define (script-fu-layers-view-current-only image drawable)
    (script-fu-layers-view-none image drawable)
    (if (not (= 0 (car (gimp-drawable-is-layer drawable))))
        (gimp-layer-set-visible drawable TRUE))
)
(define (script-fu-layers-delete-hidden image drawable)
 (let* ((layers (gimp-image-get-layers image))
	    (number-layers (car layers))
	    (layer-array (cadr layers))
	    (layer-count 0)
	    (layer))
    (gimp-image-undo-group-start image)
    (set! layer-count 0)
    (while (< layer-count number-layers)
           (set! layer (aref layer-array layer-count))
           (if (= (car (gimp-layer-get-visible layer)) FALSE)
               (gimp-image-remove-layer image layer))
           (set! layer-count (+ layer-count 1)))
    (gimp-image-undo-group-end image)
    (gimp-displays-flush)))

;Main Procedure 
;
; options definitions
;
(define (script-fu-bling-text text
			       size
			       font
			       text-color
                               ssize
                               bg-color
                               shadow-color
			       sblur
                               shx
                               shy
                               sho
                               stype
                               lpat
                               lani
			       trans?
                               raw)

  (let* ((img (car (gimp-image-new 256 256 RGB)))
	 (old-fg (car (gimp-palette-get-foreground)))
         (tmp (car (gimp-palette-set-foreground text-color)))
	 (text-layer (car (gimp-text-fontname img -1 0 0 text (+ (/ size 20) 4) TRUE size PIXELS font)))  ;Create text layers
;	 (text-layer2 (car (gimp-text-fontname img -1 0 0 text 10 TRUE size PIXELS font)))
;         (text-layer3 (car (gimp-text-fontname img -1 0 0 text 10 TRUE size PIXELS font)))
	 (text-layer2 (car (gimp-layer-copy text-layer TRUE)))	;add
         (text-layer3 (car (gimp-layer-copy text-layer TRUE)))	;add
        )
;
; Main Body
;

    (gimp-image-undo-disable img)
(if (= lani TRUE)
(begin
    (gimp-image-add-layer img text-layer2 0)	;add
    (gimp-image-add-layer img text-layer3 0)	;add
))
    (apply-bling-text-effect img text-layer text-layer2 text-layer3 bg-color text-color shadow-color sblur shx shy sho stype lpat ssize lani trans? raw)
    (gimp-selection-none img)
    (gimp-palette-set-foreground old-fg)
    (gimp-image-undo-enable img)
    (gimp-display-new img)
))
;
; End of Main body
;
;
; User Options
;
(script-fu-register "script-fu-bling-text"
		    "<Toolbox>/Xtns/Script-Fu/Logos2/Bling text..."
		    "Creates Bling text with a drop shadow"
		    "Scott Mosteller"
		    "Scott Mosteller"
		    "2007"
		    ""
		    SF-STRING     _"Text"               "ICE"
		    SF-ADJUSTMENT _"Font size (pixels)" '(200 2 1000 1 10 0 1)
		    SF-FONT       _"Font"               "Arial Black,"
		    SF-COLOR      _"Stroke color"       '(0 0 0)
                    SF-ADJUSTMENT _"Stroke (pixels)"    '(2 0 10 1 1 0 1)
		    SF-COLOR      _"Background color"   '(229 249 253)
		    SF-COLOR      _"Shadow color"       '(255 255 255)
                    SF-ADJUSTMENT _"Shadow blur"    '(3 0 100 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Offset X"    '(5 0 100 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Offset Y"    '(5 0 100 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Opacity"     '(60 1 100 1 1 0 1)
                    SF-OPTION     _"Sparkle Type"       '("Tiny Stars" "Sparkle" "Pixel-Bling" "Star-Blur" "Mini-sparkle" "Bubbles" "Bubble Fizz" "Bling Stew" "Bling Stew No Fizz" "Hearts TBG" "Sparse-Sparkle""Little Stars Multicolor""Stars Only" "Stars Only Small" "Stars Pulse" "Stars Pulse2" "Whitenoise")
                    SF-PATTERN    _"Fill Pattern"       "Rain"
                    SF-TOGGLE     _"Animate?"           TRUE
                    SF-TOGGLE     _"Background Transparent?"   FALSE
                    SF-TOGGLE     _"Raw Layers Only?(not semi-flatten)"   FALSE
)

(define (script-fu-bling-textimg img
			      text-layer
			       size
			       text-color
                               ssize
                               bg-color
                               shadow-color
			       sblur
                               shx
                               shy
                               sho
                               stype
                               lpat
                               lani
			       trans?
			       raw
                               )

  (let* (
	 (old-fg (car (gimp-palette-get-foreground)))
         (tmp (car (gimp-palette-set-foreground text-color)))
;	 (text-layer (car (gimp-text-fontname img -1 0 0 text (+ (/ size 20) 4) TRUE size PIXELS font)))  ;Create text layers
;	 (text-layer2 (car (gimp-text-fontname img -1 0 0 text 10 TRUE size PIXELS font)))
;         (text-layer3 (car (gimp-text-fontname img -1 0 0 text 10 TRUE size PIXELS font)))
	 (text-layer2 (car (gimp-layer-copy text-layer TRUE)))	;add
         (text-layer3 (car (gimp-layer-copy text-layer TRUE)))	;add
        )
;
; Main Body
;

(script-fu-layers-view-current-only img text-layer)	;Tosilscript-fu

(if (= lani TRUE)
(begin
    (gimp-image-add-layer img text-layer2 0)	;add
    (gimp-image-add-layer img text-layer3 0)	;add
))
    (apply-bling-text-effect img text-layer text-layer2 text-layer3 bg-color text-color shadow-color sblur shx shy sho stype lpat ssize lani trans? raw)
    (gimp-selection-none img)
    (gimp-palette-set-foreground old-fg)
    (gimp-displays-flush)
))

; User Options
;

;摜H{
(define (script-fu-bling-textimgh img
			      text-layer
			       size
			       text-color
                               ssize
                               bg-color
                               shadow-color
			       sblur
                               shx
                               shy
                               sho
                               stype
                               lpat
                               lani
			       trans?
			       raw
                               )
  (let* (
	(img2 (car (gimp-channel-ops-duplicate img)))
	(drawable2 (car (gimp-image-get-active-layer img2)))
	)
	(gimp-image-undo-disable img2)
	(script-fu-layers-view-current-only img2 drawable2)	;Tosilscript-fu
	(script-fu-layers-delete-hidden img2 drawable2)		;Tosilscript-fu

	(script-fu-bling-textimg img2
			      drawable2
			       size
			       text-color
                               ssize
                               bg-color
                               shadow-color
			       sblur
                               shx
                               shy
                               sho
                               stype
                               lpat
                               lani
			       trans?
			       raw
                               )
	(gimp-image-undo-enable img2)
	(gimp-display-new img2)
  )
)

(script-fu-register "script-fu-bling-textimgh"
		    "<Image>/Script-Fu/Animators/Bling alpha..."
		    "Creates Bling text with a drop shadow"
		    "Scott Mosteller"
		    "Scott Mosteller"
		    "2007"
		    "RGBA"
		SF-IMAGE       	"Image" 0
		SF-DRAWABLE    	"Drawable" 0
		    SF-ADJUSTMENT _"size (pixels)" '(200 2 1000 1 10 0 1)
		    SF-COLOR      _"Stroke color"       '(0 0 0)
                    SF-ADJUSTMENT _"Stroke (pixels)"    '(2 0 10 1 1 0 1)
		    SF-COLOR      _"Background color"   '(229 249 253)
		    SF-COLOR      _"Shadow color"       '(255 255 255)
                    SF-ADJUSTMENT _"Shadow blur"    '(3 0 100 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Offset X"    '(5 0 100 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Offset Y"    '(5 0 100 1 1 0 1)
                    SF-ADJUSTMENT _"Shadow Opacity"     '(60 1 100 1 1 0 1)
                    SF-OPTION     _"Sparkle Type"       '("Tiny Stars" "Sparkle" "Pixel-Bling" "Star-Blur" "Mini-sparkle" "Bubbles" "Bubble Fizz" "Bling Stew" "Bling Stew No Fizz" "Hearts TBG" "Sparse-Sparkle""Little Stars Multicolor""Stars Only" "Stars Only Small" "Stars Pulse" "Stars Pulse2" "Whitenoise")
                    SF-PATTERN    _"Fill Pattern"       "Rain"
                    SF-TOGGLE     _"Animate?"           TRUE
                    SF-TOGGLE     _"Background Transparent?"   FALSE
                    SF-TOGGLE     _"Raw Layers Only?(not semi-flatten)"   FALSE
)

;
;
; Apply Bing Text Procedure
;
; Define procedure and declare local variables
;
(define (apply-bling-text-effect img
				  logo-layer
                                  logo-layer2
                                  logo-layer3
				  bg-color
				  text-color
                                  shadow-color
				  sblur
                                  shx
                                  shy
                                  sho
                                  stype
                                  lpat
                                  ssize
                                  lani
				  trans?
                                  raw)
  (let* ((width (car (gimp-drawable-width logo-layer)))
	 (height (car (gimp-drawable-height logo-layer)))
	 (shadow-layer (car (gimp-layer-new img width height RGBA-IMAGE "Shadow" sho NORMAL-MODE)))
         (shadow-layer2 (car (gimp-layer-new img width height RGBA-IMAGE "Shadow1" sho NORMAL-MODE)))
	 (shadow-layer3 (car (gimp-layer-new img width height RGBA-IMAGE "Shadow2" sho NORMAL-MODE)))
	 (bg-layer (car (gimp-layer-new img width height RGB-IMAGE "Background" 100 NORMAL-MODE)))
	 (bg-layer2)
	 (bg-layer3)
	 (tmpl1 0) 
         (tmpl2 0)
         (tmpl3 0)
         (tmps1 0)
         (tmps2 0)
         (tmps3 0)
         (old-fg (car (gimp-palette-get-foreground)))
         (old-bg (car (gimp-palette-get-background)))
         (old-pat (car (gimp-patterns-get-pattern)))
	 (shou)
   )

;
; Push context to save
;
;;;;;   (gimp-context-push)
   (gimp-selection-none img)
   (script-fu-util-image-resize-from-layer img logo-layer)

;First, change image resize.
   (gimp-image-resize img (+ (+ width shx) (* sblur 1.1)) (+ (+ height shy) (* sblur 1.1)) (/ (* sblur 1.1) 2) (/ (* sblur 1.1) 2))
;
; Add a background layer
;
   (gimp-image-add-layer img bg-layer 3)
   (gimp-layer-resize bg-layer (+ (+ width shx) (* sblur 1.1)) (+ (+ height shy) (* sblur 1.1)) 0 0)
   (gimp-palette-set-foreground text-color)
   (gimp-palette-set-background bg-color)
   (gimp-edit-fill bg-layer BACKGROUND-FILL)
   (set! bg-layer2 (car (gimp-layer-copy bg-layer FALSE)))	;add
   (set! bg-layer3 (car (gimp-layer-copy bg-layer FALSE)))	;add
;
; Create shadow layer 1
;
   (gimp-image-add-layer img shadow-layer -1)
   (gimp-layer-resize shadow-layer (+ (+ width shx) (* sblur 1.1)) (+ (+ height shy) (* sblur 1.1)) 0 0)
   (gimp-edit-clear shadow-layer)
   (gimp-selection-layer-alpha logo-layer)
;   (gimp-palette-set-background '(0 0 0))
   (gimp-selection-feather img sblur)
   (gimp-palette-set-background shadow-color)
   (gimp-edit-fill shadow-layer BACKGROUND-FILL)
   (gimp-layer-translate shadow-layer shx shy)
;   (set! swidth (car (gimp-drawable-width shadow-layer)))	;add 2.0
;   (set! sheight (car (gimp-drawable-height shadow-layer)))	;add 2.0
;;;;;   (gimp-image-resize-to-layers img)
;
; Resize and fill BG layer
;
;   (gimp-layer-resize-to-image-size bg-layer)
;   (gimp-selection-none img)
;   (gimp-palette-set-background bg-color)
;   (gimp-edit-fill bg-layer BACKGROUND-FILL)

;
; Create shadow layer 2
;
(if (= lani TRUE)
(begin
   (gimp-selection-none img)
   (gimp-image-add-layer img shadow-layer2 1)
   (gimp-layer-resize-to-image-size shadow-layer2)
   (gimp-edit-clear shadow-layer2)
   (gimp-selection-layer-alpha logo-layer2)
;   (gimp-palette-set-background '(0 0 0))
   (gimp-selection-feather img sblur)
   (gimp-palette-set-background shadow-color)
   (gimp-edit-fill shadow-layer2 BACKGROUND-FILL)
   (gimp-layer-translate shadow-layer2 shx shy)
;   (gimp-image-resize-to-layers img)
;    (gimp-image-resize img swidth sheight 0 0)
;
; Create shadow layer 3
;
   (gimp-selection-none img)
   (gimp-image-add-layer img shadow-layer3 1)
   (gimp-layer-resize-to-image-size shadow-layer3)
   (gimp-edit-clear shadow-layer3)
   (gimp-selection-layer-alpha logo-layer3)
   (gimp-palette-set-background '(0 0 0))
   (gimp-selection-feather img sblur)
   (gimp-palette-set-background shadow-color)
   (gimp-edit-fill shadow-layer3 BACKGROUND-FILL)
   (gimp-image-raise-layer img shadow-layer3)
   (gimp-layer-translate shadow-layer3 shx shy)
;   (gimp-image-resize-to-layers img)
;    (gimp-image-resize img swidth sheight 0 0)
))
;
; Fill text layers with selected pattern
;
  (gimp-by-color-select logo-layer text-color 15 2 TRUE FALSE 10 FALSE)
  (gimp-selection-shrink img ssize)
  (gimp-patterns-set-pattern lpat)
  (gimp-edit-bucket-fill logo-layer 2 0 100 0 0 0 0)
(if (= lani TRUE)
(begin
  (gimp-edit-bucket-fill logo-layer2 2 0 100 0 0 0 0)
  (gimp-edit-bucket-fill logo-layer3 2 0 100 0 0 0 0)
))

;
; Determine and set bling type
;

(if (= stype 0)
   (begin
     (set! tmps1 "Little Stars 1")
     (set! tmps2 "Little Stars 2")
     (set! tmps3 "Little Stars 3")
    ))

(if (= stype 1)
   (begin
     (set! tmps1 "Sparkle1")
     (set! tmps2 "Sparkle2")
     (set! tmps3 "Sparkle3")
    ))
(if (= stype 2)
   (begin
     (set! tmps1 "Single pixel bling1")
     (set! tmps2 "Single pixel bling2")
     (set! tmps3 "Single pixel bling3")
    ))
(if (= stype 3)
   (begin
     (set! tmps1 "Little Stars blurred1")
     (set! tmps2 "Little Stars blurred2")
     (set! tmps3 "Little Stars blurred3")
    ))
(if (= stype 4)
   (begin
     (set! tmps1 "mini-sparkle1")
     (set! tmps2 "mini-sparkle2")
     (set! tmps3 "mini-sparkle3")
    ))
(if (= stype 5)
   (begin
     (set! tmps1 "Bubbles 1")
     (set! tmps2 "Bubbles 2")
     (set! tmps3 "Bubbles 3")
    ))
(if (= stype 6)
   (begin
     (set! tmps1 "Bubble Fizz 1")
     (set! tmps2 "Bubble Fizz 2")
     (set! tmps3 "Bubble Fizz 3")
    ))
(if (= stype 7)
   (begin
     (set! tmps1 "Bling Stew 1")
     (set! tmps2 "Bling Stew 2")
     (set! tmps3 "Bling Stew 3")
    ))
(if (= stype 8)
   (begin
     (set! tmps1 "Bling Stew No Fizz 1")
     (set! tmps2 "Bling Stew No Fizz 2")
     (set! tmps3 "Bling Stew No Fizz 3")
    ))
(if (= stype 9)
   (begin
     (set! tmps1 "Hearts TBG 1")
     (set! tmps2 "Hearts TBG 2")
     (set! tmps3 "Hearts TBG 3")
    ))
(if (= stype 10)
   (begin
     (set! tmps1 "sparse-sparkle1")
     (set! tmps2 "sparse-sparkle2")
     (set! tmps3 "sparse-sparkle3")
    ))
(if (= stype 11)
   (begin
     (set! tmps1 "Little Stars Multicolor 1")
     (set! tmps2 "Little Stars Multicolor 2")
     (set! tmps3 "Little Stars Multicolor 3")
    ))

(if (= stype 12)
   (begin
     (set! tmps1 "Stars Only 1")
     (set! tmps2 "Stars Only 2")
     (set! tmps3 "Stars Only 3")
    ))

(if (= stype 13)
   (begin
     (set! tmps1 "Stars Only Small 1")
     (set! tmps2 "Stars Only Small 2")
     (set! tmps3 "Stars Only Small 3")
    ))
(if (= stype 14)
   (begin
     (set! tmps1 "Stars Pulse 1")
     (set! tmps2 "Stars Pulse 2")
     (set! tmps3 "Stars Pulse 3")
    ))
(if (= stype 15)
   (begin
     (set! tmps1 "Stars2 Pulse 1")
     (set! tmps2 "Stars2 Pulse 2")
     (set! tmps3 "Stars2 Pulse 3")
    ))

(if (= stype 16)
   (begin
     (set! tmps1 "WhiteNoise1")
     (set! tmps2 "Whitenoise2")
     (set! tmps3 "Whitenoise3")
    ))
;
; Fill text with bling patterns
;
 (gimp-patterns-set-pattern tmps1)
 (gimp-edit-bucket-fill logo-layer 2 0 100 0 0 0 0)
(if (= lani TRUE)
(begin
 (gimp-patterns-set-pattern tmps2)
 (gimp-edit-bucket-fill logo-layer2 2 0 100 0 0 0 0)
 (gimp-patterns-set-pattern tmps3)
 (gimp-edit-bucket-fill logo-layer3 2 0 100 0 0 0 0)
))

;
; Arange the layers
;
(if (= lani TRUE)
(begin
  (gimp-image-raise-layer-to-top img logo-layer3)
  (gimp-image-raise-layer-to-top img shadow-layer2)
  (gimp-image-raise-layer-to-top img logo-layer2)
))
  (gimp-image-raise-layer-to-top img shadow-layer)
  (gimp-image-raise-layer-to-top img logo-layer)

;
; Merge, Semi-flatten and Name layers only if Raw layers option not selected
;

(if (and (= lani TRUE) (= raw FALSE))
(begin
  (set! tmpl3 (car (gimp-image-merge-down img logo-layer3 0)))
  (gimp-drawable-set-name tmpl3 "TextLayer3")
  (gimp-selection-none img)
  (gimp-palette-set-background bg-color)
  (gimp-image-set-active-layer img tmpl3)
  (plug-in-semiflatten 1 img tmpl3)
;
  (set! tmpl2 (car (gimp-image-merge-down img logo-layer2 0)))
  (gimp-drawable-set-name tmpl2 "TextLayer2")
  (gimp-selection-none img)
  (gimp-palette-set-background bg-color)
  (gimp-image-set-active-layer img tmpl2)
  (plug-in-semiflatten 1 img tmpl2)
))
;

(if (= raw FALSE)
  (begin
  (set! tmpl1 (car (gimp-image-merge-down img logo-layer 0)))
  (gimp-drawable-set-name tmpl1 "TextLayer1")
  (gimp-selection-none img)
  (gimp-palette-set-background bg-color)
  (gimp-image-set-active-layer img tmpl1)
  (plug-in-semiflatten 1 img tmpl1)
  (plug-in-autocrop 1 img tmpl1)
 ))

(if (and (and (= trans? FALSE) (= lani TRUE)) (= raw FALSE))
(begin
   (set! tmpl3 (car (gimp-image-merge-down img tmpl3 0)))
   (gimp-image-add-layer img bg-layer2 2)
   (set! tmpl2 (car (gimp-image-merge-down img tmpl2 0)))
   (gimp-image-add-layer img bg-layer3 1)
   (set! tmpl1 (car (gimp-image-merge-down img tmpl1 0)))
))

(if (and (and (= trans? FALSE) (= lani TRUE)) (= raw TRUE))
(begin
   (set! tmpl3 (car (gimp-image-merge-down img logo-layer3 0)))
   (set! tmpl2 (car (gimp-image-merge-down img logo-layer2 0)))
   (set! tmpl1 (car (gimp-image-merge-down img logo-layer 0)))
   (gimp-image-add-layer img bg-layer2 1)
   (set! tmpl1 (car (gimp-image-merge-down img tmpl1 0)))
   (gimp-image-add-layer img bg-layer3 2)
   (set! tmpl2 (car (gimp-image-merge-down img tmpl2 0)))
   (set! tmpl3 (car (gimp-image-merge-down img tmpl3 0)))
))

(if (and (and (= trans? TRUE) (= lani TRUE)) (= raw TRUE))
(begin
   (set! tmpl3 (car (gimp-image-merge-down img logo-layer3 0)))
   (set! tmpl2 (car (gimp-image-merge-down img logo-layer2 0)))
   (set! tmpl1 (car (gimp-image-merge-down img logo-layer 0)))
))

(if (= trans? TRUE) (gimp-image-remove-layer img bg-layer))

    (gimp-palette-set-foreground old-fg)
    (gimp-palette-set-background old-bg)
    (gimp-patterns-set-pattern old-pat)
;
; Check animate flag and remove layers as needed 
;

;(if (= lani FALSE)
;  (begin
;   (gimp-image-remove-layer img tmpl2)
;   (gimp-image-remove-layer img tmpl3)
;   )
;    (gimp-image-remove-layer img bg-layer)
;)
;
; Make Background layer current if Raw Layers option is selected 
;
;(if (= raw TRUE)
;  (begin
;   (gimp-image-set-active-layer img bg-layer)
;   ))
;
; Restore context & done
;
;;;;;   (gimp-context-pop)
))
;
; End of Apply Procedue
;
